<?php

// Language
load_theme_textdomain('hello_wordpress', get_template_directory() . '/languages');

// Remove action
remove_action('wp_head', 'wp_generator');
remove_action('wp_head', 'rsd_link');
remove_action('wp_head', 'wlwmanifest_link');
remove_action('wp_head', 'start_post_rel_link');
remove_action('wp_head', 'index_rel_link');
remove_action('wp_head', 'adjacent_posts_rel_link');

// Remove Emojis
function disable_emojis() {
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
	remove_action( 'wp_print_styles', 'print_emoji_styles' );
	remove_action( 'admin_print_styles', 'print_emoji_styles' ); 
	remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
	remove_filter( 'comment_text_rss', 'wp_staticize_emoji' ); 
	remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
	add_filter( 'tiny_mce_plugins', 'disable_emojis_tinymce' );
	add_filter( 'wp_resource_hints', 'disable_emojis_remove_dns_prefetch', 10, 2 );
}
add_action( 'init', 'disable_emojis' );
function disable_emojis_tinymce( $plugins ) {
	if ( is_array( $plugins ) ) {
		return array_diff( $plugins, array( 'wpemoji' ) );
	} else {
		return array();
	}
}
function disable_emojis_remove_dns_prefetch( $urls, $relation_type ) {
	if ( 'dns-prefetch' == $relation_type ) {
		$emoji_svg_url = apply_filters( 'emoji_svg_url', 'https://s.w.org/images/core/emoji/2/svg/' );
		$urls = array_diff( $urls, array( $emoji_svg_url ) );
	}
	return $urls;
}

// Remove embeds
function disable_embeds_code_init() {
	remove_action( 'rest_api_init', 'wp_oembed_register_route' );
	add_filter( 'embed_oembed_discover', '__return_false' );
	remove_filter( 'oembed_dataparse', 'wp_filter_oembed_result', 10 );
	remove_action( 'wp_head', 'wp_oembed_add_discovery_links' );
	remove_action( 'wp_head', 'wp_oembed_add_host_js' );
	add_filter( 'tiny_mce_plugins', 'disable_embeds_tiny_mce_plugin' );
	add_filter( 'rewrite_rules_array', 'disable_embeds_rewrites' );
	remove_filter( 'pre_oembed_result', 'wp_filter_pre_oembed_result', 10 );
}
add_action( 'init', 'disable_embeds_code_init', 9999 );

function disable_embeds_tiny_mce_plugin($plugins) {
	return array_diff($plugins, array('wpembed'));
}

function disable_embeds_rewrites($rules) {
	foreach($rules as $rule => $rewrite) {
	if(false !== strpos($rewrite, 'embed=true')) {
		unset($rules[$rule]);
	}
	}
	return $rules;
}

// Support SVG
add_filter('upload_mimes', 'suppot_upload_svg');
 
function suppot_upload_svg($mimes = array()) {
	$mimes['svg'] = 'image/svg+xml';
	return $mimes;
}
 
// Register menu
register_nav_menus(array(
	'header' => __('Menu Header', ''),
	'footer' => __('Menu Footer', ''),
));

// Register Scripts
 
add_action( 'wp_enqueue_scripts', 'sd__custom__style__script' );
function sd__custom__style__script(){
	wp_enqueue_script('jquery');
	// slick
	wp_enqueue_style( 'slick-css', get_stylesheet_directory_uri() . '/assets/js/slick/slick.css');
	wp_register_script( 'slick-js', get_stylesheet_directory_uri() . '/assets/js/slick/slick.min.js');
	wp_enqueue_style('slick-css');
	wp_enqueue_script('slick-js');


	// waypoint
	wp_register_script( 'waypoint-js', get_stylesheet_directory_uri() . '/assets/js/jquery.waypoints.js');
	wp_enqueue_script('waypoint-js');

	// swiper
	wp_enqueue_style( 'swiper-css', get_stylesheet_directory_uri() . '/assets/js/swiper/swiper.css');
	wp_register_script( 'swiper-js', get_stylesheet_directory_uri() . '/assets/js/swiper/swiper.min.js');
	wp_enqueue_style('swiper-css');
	wp_enqueue_script('swiper-js');


	 // aos
	wp_enqueue_style( 'aos-css', get_stylesheet_directory_uri() . '/assets/js/aos/aos.css');
	wp_register_script( 'aos-js', get_stylesheet_directory_uri() . '/assets/js/aos/aos.js');
	wp_enqueue_style('aos-css');
	wp_enqueue_script('aos-js');


	// sticky
	wp_register_script( 'sticky-js', get_stylesheet_directory_uri() . '/assets/js/jquery.sticky-kit.min.js');
	wp_enqueue_script('sticky-js');

	// sticky
	wp_register_script( 'main-js', get_stylesheet_directory_uri() . '/assets/js/main.js');
	wp_enqueue_script('main-js');

}

// Registre Widgets
require ( 'widgets/recent-post.php' );
require ( 'widgets/social-media.php' );
require ( 'widgets/copyright.php' );

// Custom format date post created
function the_date_custom_post() {
	$dateDay    = ''.get_the_date('j').'';
	$dateMonth  = ''.get_the_date('M').'';
	$dateYear   = ''.get_the_date('Y').''; ?>
	<?php echo $dateDay; ?> <?php echo $dateMonth; ?>. <?php echo $dateYear; ?>
	<?php
}

// Custom excerpt
function the_excerpt_max_charlength($charlength) {
	$excerpt = get_the_excerpt();
	$charlength++;

	if ( mb_strlen( $excerpt ) > $charlength ) {
		$subex = mb_substr( $excerpt, 0, $charlength - 5 );
		$exwords = explode( ' ', $subex );
		$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
		if ( $excut < 0 ) {
			echo mb_substr( $subex, 0, $excut );
		} else {
			echo $subex;
		}
		echo '...';
	} else {
		echo $excerpt;
	}
}

add_action( 'wp_enqueue_scripts', 'load_dashicons_front_end' );
function load_dashicons_front_end() {
  wp_enqueue_style( 'dashicons' );
}

function disable_wp_responsive_images() {
	return 1;
}
add_filter('max_srcset_image_width', 'disable_wp_responsive_images');

// REFACTORY CODE | 21-02-2020 | by: miguel@kodewp.com

if ( ! function_exists( 'kwp_theme_setup' ) ) :
 
	function kwp_theme_setup() {
 		
 		// Title
		add_theme_support( 'title-tag' );

		// Suport Featured Image
		add_theme_support( 'post-thumbnails' );

		// Widget init
		function register_widgets_array() {
		  $sidebars = array (
		  	'sidebar-left'		=> 'Primario',
		  	'sidebar-right'		=> 'Secundario',
		  	'sidebar-footer-d'	=> 'Footer Dimamyc',
		  	'sidebar-footer-c1'	=> 'Footer Columna 1',
		  	'sidebar-footer-c2'	=> 'Footer Columna 2',
		  	'sidebar-footer-c3'	=> 'Footer Columna 3',
		  	'sidebar-footer-c4'	=> 'Footer Columna 4',
		  	'sidebar-responsive'	=> 'Sidebar Responsive',
		  );  
		  foreach ( $sidebars as $id => $sidebar) {
		  register_sidebar(
		  array (
		    'name'          => __( $sidebar, 'kodewp' ),
		    'id'            => $id,
		    'before_widget' => '<div class="widget-container" id="%1$s">',
		    'after_widget'  => '</div>',
		    'before_title'  => '<h3 class="widget-title">',
		    'after_title'   => '</h3>',
		      ));
		  }
		}
 
		add_action( 'widgets_init', 'register_widgets_array' );

		// LOGO WEB
		add_theme_support( 'custom-logo' );

		function kwp_theme_custom_logo_setup() {
			$defaults = array(
				'width'       => 210,
				'height'      => 95,
				'flex-height' => true,
				'flex-width'  => true,
				'header-text' => array( 'site-title', 'site-description' ),
		 );
		 add_theme_support( 'custom-logo', $defaults );
		}
		add_action( 'after_setup_theme', 'kwp_theme_custom_logo_setup' );

		// BANNER HEADER
		$args = array(
		    'flex-width'    => true,
		    'width'         => 1920,
		    'flex-height'   => true,
		    'height'        => 420,
		    'header-text'            => true,
		    'default-image' => get_template_directory_uri() . '/assets/images/banner_header.png',
		);
		add_theme_support( 'custom-header', $args );


		// BANNER TEXTOS
		add_action( 'customize_register', 'theme_header_text_customizer');

		function theme_header_text_customizer($kwp_wp_customize_theme_banner_text){

			$kwp_wp_customize_theme_banner_text->add_section('text_banner_settings_section', array(
				'title' => 'Textos banner Inicio',
				'priority'       => 90,
			));
			$kwp_wp_customize_theme_banner_text->add_setting('text_titulo_banner_setting', array(
				'default' => 'Últimas Noticias',
			));
			$kwp_wp_customize_theme_banner_text->add_control('text_titulo_banner_setting', array(
				'label' => 'Banner Titulo',
				'section' => 'text_banner_settings_section',
				'type' => 'text',
			));

			$kwp_wp_customize_theme_banner_text->add_setting('text_subtitulo_banner_setting', array(
				'default' => 'Default Text For Footer Section',
			));
			$kwp_wp_customize_theme_banner_text->add_control('text_subtitulo_banner_setting', array(
				'label' => 'Banner Subtitulo',
				'section' => 'text_banner_settings_section',
				'type' => 'text',
			));

			$kwp_wp_customize_theme_banner_text->add_setting( 'text_color_banner_setting', array(
			  	'default'   => '#FFFFFF',
			  	'transport' => 'refresh',
			  	'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_banner_text->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_banner_text, 'text_color_banner_setting', array(
			  	'section' => 'text_banner_settings_section',
			  	'label'   => esc_html__( 'Color de Textos', 'kodewp' ),
			) ) );

		}

		// STYLE HEADER
		function kwp_theme_customize_header_register( $kwp_wp_customize_theme_style_header ) {

			 $kwp_wp_customize_theme_style_header->add_section( 'style_header_setting_section' , array(
			    'title'      => 'Header',
			    'priority'   => 20,
			) );

			$kwp_wp_customize_theme_style_header->add_setting( 'style_header_setting_section_display' , array(
			    'default'     => true,
			    'transport'   => 'refresh',
			) );

			$kwp_wp_customize_theme_style_header->add_control( 'style_header_setting_section_display', array(
			  	'label' => 'Style Header',
			  	'section' => 'style_header_setting_section',
			  	'settings' => 'style_header_setting_section_display',
			  	'type' => 'radio',
			  	'choices' => array(
			    	'default'	=>	'Default',
			    	'style1'	=>	'Style # 01',
			    	'style2'	=>	'Style # 02',
			 	),
			) );

			// FONDO HEADER
			$kwp_wp_customize_theme_style_header->add_setting( 'background_header', array(
			  'default'   => '#FFFFFF',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_style_header->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_style_header, 'background_header', array(
			  	'section' => 'style_header_setting_section',
			  	'label'   => esc_html__( 'Color de Fondo', 'kodewp' ),
			) ) );

		}
		add_action( 'customize_register', 'kwp_theme_customize_header_register' );

		// STYLE FOOTER
		function kwp_theme_customize_footer_register( $kwp_wp_customize_theme_style_footer ) {

			// FONDO FOOTER

			 $kwp_wp_customize_theme_style_footer->add_section( 'style_footer_setting_section' , array(
			    'title'      => 'Footer',
			    'priority'   => 20,
			) );

			$kwp_wp_customize_theme_style_footer->add_setting( 'background_footer', array(
			  'default'   => '#FFFFFF',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_style_footer->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_style_footer, 'background_footer', array(
			  	'section' => 'style_footer_setting_section',
			  	'label'   => esc_html__( 'Color de Fondo', 'kodewp' ),
			) ) );

		}
		add_action( 'customize_register', 'kwp_theme_customize_footer_register' );

		// COLORES WEB
		function kwp_theme_customize_register( $kwp_wp_customize_theme_color ) {


			// FONDO SITE
			$kwp_wp_customize_theme_color->add_setting( 'background_site', array(
			  'default'   => '#FFFFFF',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_color->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_color, 'background_site', array(
			  'section' => 'colors',
			  'label'   => esc_html__( 'Color de Fondo del sitio', 'kodewp' ),
			) ) );


			// COLOR MENUS HEADER
			$kwp_wp_customize_theme_color->add_setting( 'color_menu_header', array(
			  'default'   => '#000000',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_color->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_color, 'color_menu_header', array(
			  'section' => 'colors',
			  'label'   => esc_html__( 'Color menu header', 'kodewp' ),
			) ) );

			// COLOR MENUS HEADER HOVER
			$kwp_wp_customize_theme_color->add_setting( 'color_menu_header_hover', array(
			  'default'   => '#000000',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_color->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_color, 'color_menu_header_hover', array(
			  'section' => 'colors',
			  'label'   => esc_html__( 'Color menu header hover', 'kodewp' ),
			) ) );

			// COLOR PRIMARIO
			$kwp_wp_customize_theme_color->add_setting( 'color_primario', array(
			  	'default'   => '#3b8dbd',
			  	'transport' => 'refresh',
			  	'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_color->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_color, 'color_primario', array(
				'section' => 'colors',
				'label'   => esc_html__( 'Color Primario', 'kodewp' ),
			) ) );

			// COLOR SECUNDARIO
			$kwp_wp_customize_theme_color->add_setting( 'color_secundario', array(
			  'default'   => '#82b965',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_color->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_color, 'color_secundario', array(
			  'section' => 'colors',
			  'label'   => esc_html__( 'Color Secundario', 'kodewp' ),
			) ) );

			// COLOR DE TEXTO
			$kwp_wp_customize_theme_color->add_setting( 'color_texto', array(
			  'default'   => '#000000',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_color->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_color, 'color_texto', array(
			  'section' => 'colors',
			  'label'   => esc_html__( 'Color de Texto', 'kodewp' ),
			) ) );

			// FONDO BOXED
			$kwp_wp_customize_theme_color->add_setting( 'background_boxed', array(
			  'default'   => '#FFFFFF',
			  'transport' => 'refresh',
			  'sanitize_callback' => 'sanitize_hex_color',
			) );

			$kwp_wp_customize_theme_color->add_control( new WP_Customize_Color_Control( $kwp_wp_customize_theme_color, 'background_boxed', array(
			  'section' => 'colors',
			  'label'   => esc_html__( 'Fondo Boxes', 'kodewp' ),
			) ) );

		}
		add_action( 'customize_register', 'kwp_theme_customize_register' );

		// CSS PERSONALIZADO
		function theme_get_customizer_css() {
			ob_start();

			$color_primario = get_theme_mod( 'color_primario', '' );
			$color_secundario = get_theme_mod( 'color_secundario', '' );
			$color_texto = get_theme_mod( 'color_texto', '' );
			$background_boxed = get_theme_mod( 'background_boxed', '' );
			$background_site = get_theme_mod( 'background_site', '' );
			$background_header = get_theme_mod( 'background_header', '' );
			$background_footer = get_theme_mod( 'background_footer', '' );
			$color_menu_header = get_theme_mod( 'color_menu_header', '' );
			$color_menu_header_hover = get_theme_mod( 'color_menu_header_hover', '' );
			$color_text_banner = get_theme_mod( 'text_color_banner_setting', '' );
			?>

			body{
				background: <?php echo $background_site; ?>;	
			}
			.header_fixed, .header_fixed.scroll {
				background: <?php echo $background_header; ?>;
			}
			header nav ul.menu-header li a{
				color: <?php echo $color_menu_header; ?>;
			}
			header nav ul.menu-header li:hover a,
			header nav ul.menu-header li.current-menu-item a{
				color: <?php echo $color_menu_header_hover; ?>;
			}
			footer.footer{
				background: <?php echo $background_footer; ?>;
			}
			.block__news__categories a, .block__news__trending__item span, .block__news__categories .post-categories li a, .header_content .link__title{
				color: <?php echo $color_primario; ?>;
			}
			.block__news__content, .result__item h2, .header_list li a{
				color: <?php echo $color_texto; ?>;
			}
			.content__banner__header__page h1,
			.content__banner__header__page h2,
			.content__banner__header__page h3,
			.content__banner__header__page p{
				color: <?php echo $color_text_banner; ?> !important;
			}
			.block__news__author__name, .block__news__date, .block__news__title h3, .block__news__trending__item h3, .block__news__trending__item__block__title h4, .block__news__trending__item:first-child span, .news__detail__content__content, .news__detail__content__tag, .news__detail__content__author__name, .title__general__title h3, .blog__detail__wrap__item__text span, .blog__detail__wrap__item__text h3, .content__banner__header__page h3, .footer_redes_icons a, .searchform label, .calendar_wrap caption, .calendar_wrap td, .calendar_wrap td a, .menu-menu-header-container ul li a, .block__result__search h1, .result__item__text, .widget-title, .form__prin button, .form__prin input::placeholder, .search__no__result p, .block__result__search  .search__no__result strong, .header_list li.menu-blog a, .header_list li.current-menu-item a, .footer_copyright, .footer_subtitle, .footer_team_text, .footer_team_developer{
				color: <?php echo $color_secundario; ?>;
			}
			.block__news__content p{
				font-family: 'ProximaNova-Regular', sans-serif;
			}
			.block__news__category li a, .tagcloud a{
				background: <?php echo $color_primario; ?>;
				color: <?php echo $color_secundario; ?>;
			}
			.block__news__info, .block__news__trending__item{
				background-color: <?php echo $background_boxed; ?>;
			}
			.news__detail__redes__item{
				color: <?php echo $color_primario; ?>;
				border: 1px solid <?php echo $color_primario; ?>;
			}
			.form__prin input[type=text]{
				border-bottom: 1px solid <?php echo $color_texto; ?>;
				color: <?php echo $color_secundario; ?>;
			}
			.news__detail__content__tag a, .block__news__tags__item a{
				color: <?php echo $color_primario; ?>;
	    		background: <?php echo $color_secundario; ?>;
			}
			.pagination__block  a, .pagination__block span{
				color: <?php echo $color_secundario; ?>;
	    		background: <?php echo $color_primario; ?>;
			}
			.pagination__block .current{
				color: <?php echo $color_primario; ?>;
	    		background: <?php echo $color_secundario; ?>;
			}
			.error__wrap a{
				color: <?php echo $color_primario; ?>;
			}
			.menu_line{
				background: <?php echo $color_primario; ?>;
			}
			@media screen and (min-width: 1025px) {
				.block__news__item:hover .block__news__title h3, .block__news__author__name:hover, .result__item:hover h2{
					color: <?php echo $color_primario; ?>;
				}
				.block__news__trending__item:hover span{
					color: <?php echo $color_secundario; ?>;
				}
				.news__detail__redes__item:hover, .news__detail__content__tag a:hover, .block__news__tags__item a:hover{
					background: <?php echo $color_primario; ?>;
					color: <?php echo $color_secundario; ?>;
				}
				.pagination__block  a:hover, .pagination__block span:hover{
					color: <?php echo $color_primario; ?>;
		    		background: <?php echo $color_secundario; ?>;
				}
				.header_list li a:hover{
					color: <?php echo $color_secundario; ?>;
				}
			}
			<?php
			$css = ob_get_clean();
			return $css;
		}

		function theme_enqueue_styles() {
			wp_enqueue_style( 'theme-styles', get_stylesheet_uri() );
			$custom_css = theme_get_customizer_css();
			wp_add_inline_style( 'theme-styles', $custom_css );
		}

		add_action( 'wp_enqueue_scripts', 'theme_enqueue_styles' );

		// PAGINACION
		function twentynineteen_the_posts_navigation() {
			 
		}

	};
endif;
add_action( 'after_setup_theme', 'kwp_theme_setup' );

//add_filter('show_admin_bar', '__return_true');

/*
----------------------------------
[social_media_sd]
----------------------------------
*/

function wp_custom_social_media($content = null) {
  ob_start(); ?>
	<?php if( have_rows('redes_sociales', 'options') ): ?>
		  <ul >
			<?php while( have_rows('redes_sociales', 'options') ): the_row(); ?>
			  <?php 
				$name_select_sub_field = (get_sub_field_object('tipo_red_social'));
				$name_sub_field = get_sub_field('tipo_red_social');
				$label_select = ($name_select_sub_field['choices'][$name_sub_field]);
			  ?>
			  <?php if( get_sub_field('url_red_social', 'options') ) { ?>
				<li>
				  <a class="icon-<?php the_sub_field( 'tipo_red_social' ); ?>" href="<?php the_sub_field('url_red_social', 'options'); ?>" target="_blank"> </a>
				</li>
			  <?php } ?>
			<?php endwhile; ?>
		  </ul>
	<?php endif;
  $content = ob_get_contents();
  ob_end_clean();
  return $content;  
}
add_shortcode('social_media_sd', 'wp_custom_social_media');


// QUITAR GUTENBERG

add_filter( 'gutenberg_can_edit_post_type', '__return_false' );
add_filter('use_block_editor_for_post_type', '__return_false', 100);

//-/QUITAR GUTENBERG