<?php

/**
 * @author Miguel Fuentes <miguel@kodewp.com>
 */

class Udep_Social_Icons_Widget extends WP_Widget {

	protected $version = '1.0.0';
	protected $defaults;
	protected $sizes;
	protected $profiles;
	protected $active_instances;
	protected $disable_css_output;

	function __construct() {

		$this->defaults = apply_filters( 'simple_social_default_styles', array(
			'title'                  => '',
			'new_window'             => 0,
			'size'                   => 36,
			'border_radius'          => 3,
			'icon_color'             => '#ffffff',
			'icon_color_hover'       => '#ffffff',
			'background_color'       => '#999999',
			'background_color_hover' => '#666666',
			'alignment'              => '',
			'facebook'               => '',
			'instagram'              => '',
			'linkedin'               => '',
			'twitter'                => '',
			'youtube'                => '',
			'vimeo'                  => '',
		) );

		$this->profiles = apply_filters( 'simple_social_default_profiles', array(
			'facebook' => array(
				'label'   => __( 'Facebook URL', 'udep' ),
				'pattern' => $this->get_icon_markup( 'facebook', __( 'Facebook', 'udep' ) ),
			),
			'instagram' => array(
				'label'   => __( 'Instagram URL', 'udep' ),
				'pattern' => $this->get_icon_markup( 'instagram', __( 'Instagram', 'udep' ) ),
			),
			'twitter' => array(
				'label'   => __( 'Twitter URL', 'udep' ),
				'pattern' => $this->get_icon_markup( 'twitter', __( 'Twitter', 'udep' ) ),
			),
			'linkedin' => array(
				'label'   => __( 'Linkedin URL', 'udep' ),
				'pattern' => $this->get_icon_markup( 'linkedin', __( 'LinkedIn', 'udep' ) ),
			),
			'youtube' => array(
				'label'   => __( 'YouTube URL', 'udep' ),
				'pattern' => $this->get_icon_markup( 'youtube', __( 'YouTube', 'udep' ) ),
			),
			'vimeo' => array(
				'label'   => __( 'Vimeo URL', 'udep' ),
				'pattern' => $this->get_icon_markup( 'vimeo', __( 'Vimeo', 'udep' ) ),
			),
		) );

		$this->disable_css_output = apply_filters( 'simple_social_disable_custom_css', false );

		$widget_ops = array(
			'classname'   => 'udep-social-icons',
			'description' => __( 'Displays select social icons.', 'udep' ),
		);

		$control_ops = array(
			'id_base' => 'udep-social-icons',
		);

		$this->active_instances = array();

		parent::__construct( 'udep-social-icons', __( 'KODEWP - Social Icons', 'udep' ), $widget_ops, $control_ops );

		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_css' ) );

		add_action( 'wp_footer', array( $this, 'css' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'load_color_picker' ) );
		add_action( 'admin_footer-widgets.php', array( $this, 'print_scripts' ), 9999 );

	}

	// LOAD COLOR-PICKER
	function load_color_picker( $hook ) {
		if( 'widgets.php' != $hook )
			return;
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker' );
			wp_enqueue_script( 'underscore' );
	}

	// PRINT SCRIPTS
	function print_scripts() {
		?>
		<script>
			( function( $ ){
				function initColorPicker( widget ) {
					widget.find( '.ssiw-color-picker' ).wpColorPicker( {
						change: function ( event ) {
							var $picker = $( this );
							_.throttle(setTimeout(function () {
								$picker.trigger( 'change' );
							}, 5), 250);
						},
						width: 235,
					});
				}

				function onFormUpdate( event, widget ) {
					initColorPicker( widget );
				}

				$( document ).on( 'widget-added widget-updated', onFormUpdate );

				$( document ).ready( function() {
					$( '#widgets-right .widget:has(.ssiw-color-picker)' ).each( function () {
						initColorPicker( $( this ) );
					} );
				} );
			}( jQuery ) );
		</script>
		<?php
	}

	// WIDGET FORM
	function form( $instance ) {

		/** Merge with defaults */
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>

		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'udep' ); ?></label> <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" /></p>

		<p><label><input id="<?php echo $this->get_field_id( 'new_window' ); ?>" type="checkbox" name="<?php echo $this->get_field_name( 'new_window' ); ?>" value="1" <?php checked( 1, $instance['new_window'] ); ?>/> <?php esc_html_e( 'Open links in new window?', 'udep' ); ?></label></p>

		<?php if ( ! $this->disable_css_output ) { ?>

			<p><label for="<?php echo $this->get_field_id( 'size' ); ?>"><?php _e( 'Icon Size', 'udep' ); ?>:</label> <input id="<?php echo $this->get_field_id( 'size' ); ?>" name="<?php echo $this->get_field_name( 'size' ); ?>" type="text" value="<?php echo esc_attr( $instance['size'] ); ?>" size="3" />px</p>

			<hr style="background: #ccc; border: 0; height: 1px; margin: 20px 0;" />

			<p><label for="<?php echo $this->get_field_id( 'background_color' ); ?>"><?php _e( 'Icon Color:', 'udep' ); ?></label><br /> <input id="<?php echo $this->get_field_id( 'icon_color' ); ?>" name="<?php echo $this->get_field_name( 'icon_color' ); ?>" type="text" class="ssiw-color-picker" data-default-color="<?php echo esc_attr( $this->defaults['icon_color'] ); ?>" value="<?php echo esc_attr( $instance['icon_color'] ); ?>" size="6" /></p>

			<p><label for="<?php echo $this->get_field_id( 'background_color_hover' ); ?>"><?php _e( 'Icon Hover Color:', 'udep' ); ?></label><br /> <input id="<?php echo $this->get_field_id( 'icon_color_hover' ); ?>" name="<?php echo $this->get_field_name( 'icon_color_hover' ); ?>" type="text" class="ssiw-color-picker" data-default-color="<?php echo esc_attr( $this->defaults['icon_color_hover'] ); ?>" value="<?php echo esc_attr( $instance['icon_color_hover'] ); ?>" size="6" /></p>

			<hr style="background: #ccc; border: 0; height: 1px; margin: 20px 0;" />
		<?php } ?>

		<?php
		foreach ( (array) $this->profiles as $profile => $data ) {

			//printf( '<p><label for="%s">%s:</label></p>', esc_attr( $this->get_field_id( $profile ) ), esc_attr( $data['label'] ) );
			printf( '<p><input type="text" id="%s" name="%s" value="%s" placeholder="%s" class="widefat" />',
				esc_attr( $this->get_field_id( $profile ) ), esc_attr( $this->get_field_name( $profile ) ), $instance[ $profile ], esc_attr( $data['label'] ));
			printf( '</p>' );

		}

	}

	// VALIDACION and sanitization.
	function update( $newinstance, $oldinstance ) {

		// Fields that can be transparent if their values are unset.
		$can_be_transparent = array(
			'background_color',
			'background_color_hover',
		);

		foreach ( $newinstance as $key => $value ) {

			/** Border radius and Icon size must not be empty, must be a digit */
			if ( ( 'border_radius' == $key || 'size' == $key ) && ( '' == $value || ! ctype_digit( $value ) ) ) {
				$newinstance[ $key ] = 0;
			}

			/** Accept empty colors for permitted keys. */
			elseif ( in_array( $key, $can_be_transparent, true ) && '' == trim( $value ) ) {
				$newinstance[ $key ] = '';
			}

			/** Validate hex code colors */
			elseif ( strpos( $key, '_color' ) && 0 == preg_match( '/^#(([a-fA-F0-9]{3}$)|([a-fA-F0-9]{6}$))/', $value ) ) {
				$newinstance[ $key ] = $oldinstance[ $key ];
			}

			/** Sanitize Profile URIs */
			elseif ( array_key_exists( $key, (array) $this->profiles ) && ! is_email( $value ) && ! 'phone' === $key ) {
				$newinstance[ $key ] = esc_url( $newinstance[ $key ] );
			}
		}

		return $newinstance;

	}

	// WIDGET OUTPUT
	function widget( $args, $instance ) {

		extract( $args );

		/** Merge with defaults */
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		echo $before_widget;

			if ( ! empty( $instance['title'] ) )
				echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;

			$output = '';

			$profiles = (array) $this->profiles;

			foreach ( $profiles as $profile => $data ) {

				if ( empty( $instance[ $profile ] ) )
					continue;

				$new_window = $instance['new_window'] ? 'target="_blank" rel="noopener noreferrer"' : '';

				if ( is_email( $instance[ $profile ] ) || false !== strpos( $instance[ $profile ], 'mailto:' ) )
					$new_window = '';

				if ( is_email( $instance[ $profile ] ) ) {
					$output .= sprintf( $data['pattern'], 'mailto:' . esc_attr( antispambot( $instance[ $profile ] ) ), $new_window );
				} elseif ( 'phone' === $profile ) {
					$output .= sprintf( $data['pattern'], 'tel:' . esc_attr( antispambot( $instance[ $profile ] ) ), $new_window );
				} else {
					$output .= sprintf( $data['pattern'], esc_url( $instance[ $profile ] ), $new_window );
				}

			}

			if ( $output ) {
				$output = str_replace( '{WIDGET_INSTANCE_ID}', $this->number, $output );
				printf( '<ul class="list_icons_socialmedia %s">%s</ul>', $instance['alignment'], $output );
			}

		echo $after_widget;

		$this->active_instances[] = $this->number;

	}

	function enqueue_css() {

		wp_enqueue_style( 'udep-social-icons-font', esc_url( $cssfile ), array(), $this->version, 'all' );

		if ( ! function_exists( 'is_amp_endpoint' ) || ( function_exists( 'is_amp_endpoint' ) && ! is_amp_endpoint() ) ) {
			wp_enqueue_script('svg-x-use', get_template_directory_uri() . '/widgets/assets/svgxuse.js', array(), '1.1.21' );
		}
	}

	// CUSTOM CSS
	function css() {

		/** Pull widget settings, merge with defaults */
		$all_instances = $this->get_settings();

		$css = '';

		foreach ( $this->active_instances as $instance_id ) {
			// Skip if info for this instance does not exist - this should never happen.
			if ( ! isset( $all_instances[ $instance_id ] ) || $this->disable_css_output ) {
				continue;
			}

			$instance = wp_parse_args( $all_instances[ $instance_id ], $this->defaults );

			$font_size    = round( (int) $instance['size'] / 2 );


			$css .= '
 
			#udep-social-icons-' . $instance_id . ' ul li a img{
				width: ' . $instance['size'] . 'px;
			}
			svg.icon-sm path { 
				fill: ' . $instance['icon_color'] . ' !important;
				transition: all .3s ease-in-out;
			}
			li:hover svg.icon-sm path { fill: ' . $instance['icon_color_hover'] . ' !important; }

			';

		}

		// Minify a bit.
		$css = str_replace( "\t", '', $css );
		$css = str_replace( array( "\n", "\r" ), ' ', $css );

		echo '<style type="text/css" media="screen">' . $css . '</style>';

	}

	function get_icon_markup( $icon, $label ) {
		$markup = '<li class="ssi-' . $icon . '"><a href="%s" %s>';
		$markup .= '<img class="icon-sm" src="' . esc_url( get_template_directory_uri() . '/widgets/assets/icons/SVG/' . $icon ) . '.svg">';
		$markup .= '</a></li>';

		return apply_filters( 'simple_social_icon_html', $markup, $icon, $label );
	}

	public static function plugin_uninstall() {
		delete_option( 'widget_udep-social-icons' );
	}

}

register_uninstall_hook( __FILE__, array( 'Udep_Social_Icons_Widget', 'plugin_uninstall' ) );

add_action( 'widgets_init', 'usiw_load_widget' );

function usiw_load_widget() {

	register_widget( 'Udep_Social_Icons_Widget' );

}